==> ij-segment-wrapper-2.5.0.tgz: package/lib/gtmMiddleware.js <==
import _extends from "@babel/runtime/helpers/esm/extends";

var hasUserConsents = function hasUserConsents(integrations) {
  return integrations.All !== false;
};
/**
 * We only want to track in GTM those events who have
 * been tracked by the backend already
 */


export var gtmMiddleware = function gtmMiddleware(_ref) {
  var payload = _ref.payload,
      next = _ref.next,
      _ref$whitelist = _ref.whitelist,
      whitelist = _ref$whitelist === void 0 ? [] : _ref$whitelist;
  var _payload$obj = payload.obj,
      integrations = _payload$obj.integrations,
      event = _payload$obj.event,
      properties = _payload$obj.properties;
  var eventAlreadyTracked = false;
  var isWhitelistEvent = whitelist.includes(event);

  if (properties) {
    eventAlreadyTracked = properties.segment_event_already_tracked;
    delete properties.segment_event_already_tracked;
  } // if its already tracked, the backend will have send already the anonymous
  // info to segment and s3 so the frontend should do nothing at all


  if (!hasUserConsents(integrations) && eventAlreadyTracked) {
    payload.obj.integrations = {
      All: false
    };
    return next(payload);
  }

  if (!hasUserConsents(integrations) || isWhitelistEvent || !eventAlreadyTracked) {
    return next(payload);
  } // activates GTM only


  payload.obj.integrations = {
    All: false,
    'Google Tag Manager': true
  };
  next(payload);
};
/**
 * Middleware factory to pass a whitelist to the gtmMiddleware function
 */

export var makeGtmMiddleware = function makeGtmMiddleware(_temp) {
  var _ref2 = _temp === void 0 ? {} : _temp,
      _ref2$whitelist = _ref2.whitelist,
      whitelist = _ref2$whitelist === void 0 ? [] : _ref2$whitelist;

  return function (params) {
    gtmMiddleware(_extends({}, params, {
      whitelist: whitelist
    }));
  };
};

==> ij-segment-wrapper-3.2.0.tgz: package/lib/gtmMiddleware.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
var hasUserConsents = function hasUserConsents(integrations) {
  return integrations.All !== false;
};

/**
 * We only want to track in GTM those events who have
 * been tracked by the backend already
 */
export var gtmMiddleware = function gtmMiddleware(_ref) {
  var payload = _ref.payload,
    next = _ref.next,
    _ref$whitelist = _ref.whitelist,
    whitelist = _ref$whitelist === void 0 ? [] : _ref$whitelist;
  var _payload$obj = payload.obj,
    integrations = _payload$obj.integrations,
    event = _payload$obj.event,
    properties = _payload$obj.properties;
  var eventAlreadyTracked = false;
  var isWhitelistEvent = whitelist.includes(event);
  if (properties) {
    eventAlreadyTracked = properties.segment_event_already_tracked;
    delete properties.segment_event_already_tracked;
  }

  // if its already tracked, the backend will have send already the anonymous
  // info to segment and s3 so the frontend should do nothing at all
  if (!hasUserConsents(integrations) && eventAlreadyTracked) {
    payload.obj.integrations = {
      All: false
    };
    return next(payload);
  }
  if (!hasUserConsents(integrations) || isWhitelistEvent || !eventAlreadyTracked) {
    return next(payload);
  }

  // activates GTM only
  payload.obj.integrations = {
    All: false,
    'Google Tag Manager': true
  };
  next(payload);
};

/**
 * Middleware factory to pass a whitelist to the gtmMiddleware function
 */
export var makeGtmMiddleware = function makeGtmMiddleware(_temp) {
  var _ref2 = _temp === void 0 ? {} : _temp,
    _ref2$whitelist = _ref2.whitelist,
    whitelist = _ref2$whitelist === void 0 ? [] : _ref2$whitelist;
  return function (params) {
    gtmMiddleware(_extends({}, params, {
      whitelist: whitelist
    }));
  };
};
